@@ -22,6 +22,7 @@
 #include "chxj_encoding.h"
 #include "chxj_url_encode.h"
 #include "chxj_str_util.h"
+#include "chxj_header_inf.h"
 
 
 #define GET_JXHTML(X) ((jxhtml_t *)(X))
@@ -446,7 +447,7 @@ chxj_convert_jxhtml(
   jxhtml.entryp = entryp;
   jxhtml.cookie = cookie;
 
-  chxj_set_content_type(r, "application/xhtml+xml; charset=Windows-31J");
+  chxj_set_content_type(r, chxj_header_inf_set_content_type(r, "application/xhtml+xml; charset=Windows-31J"));
 
   /*--------------------------------------------------------------------------*/
   /* The character string of the input is analyzed.                           */
@@ -705,7 +706,7 @@ s_jxhtml_start_meta_tag(void *pdoc, Node *node)
           W_L(" ");
           W_V(name);
           W_L("=\"");
-          W_L("application/xhtml+xml; charset=Windows-31J");
+          W_V(chxj_header_inf_set_content_type(r, "application/xhtml+xml; charset=SHIFT_JIS"));
           W_L("\"");
         }
         else
@@ -1399,15 +1400,18 @@ static char *
 s_jxhtml_start_form_tag(void *pdoc, Node *node) 
 {
   jxhtml_t      *jxhtml;
-  Doc          *doc;
-  request_rec  *r;
-  Attr         *attr;
+  Doc           *doc;
+  request_rec   *r;
+  Attr          *attr;
+  char          *new_hidden_tag = NULL;
+  char          *attr_method = NULL;
+  char          *attr_action = NULL;
+  char          *attr_utn    = NULL;
 
-  jxhtml = GET_JXHTML(pdoc);
-  doc   = jxhtml->doc;
-  r     = doc->r;
+  jxhtml  = GET_JXHTML(pdoc);
+  doc     = jxhtml->doc;
+  r       = doc->r;
 
-  W_L("<form");
   /*--------------------------------------------------------------------------*/
   /* Get Attributes                                                           */
   /*--------------------------------------------------------------------------*/
@@ -1416,36 +1420,57 @@ s_jxhtml_start_form_tag(void *pdoc, Node *node)
        attr = qs_get_next_attr(doc,attr)) {
     char *name  = qs_get_attr_name(doc,attr);
     char *value = qs_get_attr_value(doc,attr);
-    if (STRCASEEQ('a','A',"action",name)) {
+    if (STRCASEEQ('a','A',"action", name)) {
       /*----------------------------------------------------------------------*/
       /* CHTML 1.0                                                            */
       /*----------------------------------------------------------------------*/
-      W_L(" action=\"");
-      W_V(value);
-      W_L("\"");
+      attr_action = chxj_encoding_parameter(r, value);
+      attr_action = chxj_add_cookie_parameter(r, attr_action, jxhtml->cookie);
     }
-    else if (STRCASEEQ('m','M',"method",name)) {
+    else if (STRCASEEQ('m','M',"method", name)) {
       /*----------------------------------------------------------------------*/
       /* CHTML 1.0                                                            */
       /*----------------------------------------------------------------------*/
-      W_L(" method=\"");
-      W_V(value);
-      W_L("\"");
+      attr_method = apr_pstrdup(doc->pool, value);
     }
-    else if (STRCASEEQ('u','U',"utn",name)) {
+    else if (STRCASEEQ('u','U',"utn", name)) {
       /*----------------------------------------------------------------------*/
       /* CHTML 3.0                                                            */
       /* It is special only for CHTML.                                        */
       /*----------------------------------------------------------------------*/
-      /* ignore */
-    }
-    else if (STRCASEEQ('n','N',"name",name)) {
-      W_L(" name=\"");
-      W_V(value);
-      W_L("\"");
+      attr_utn = value;
     }
   }
+
+  int post_flag = (attr_method && strcasecmp(attr_method, "post") == 0) ? 1 : 0;
+
+  W_L("<form");
+  if (attr_action) {
+    char *q;
+    char *unused = NULL;
+    q = strchr(attr_action, '?');
+    if (q) {
+      new_hidden_tag = chxj_form_action_to_hidden_tag(r, doc->pool, attr_action, 1, post_flag, &unused, CHXJ_FALSE);
+      if (new_hidden_tag) {
+        *q = 0;
+      }
+    }
+    W_L(" action=\"");
+    W_V(attr_action);
+    W_L("\"");
+  }
+  if (attr_method) {
+    W_L(" method=\"");
+    W_V(attr_method);
+    W_L("\"");
+  }
+  if (attr_utn) {
+    W_L(" utn");
+  }
   W_L(">");
+  if (new_hidden_tag) {
+    W_V(new_hidden_tag);
+  }
   return jxhtml->out;
 }
 
@@ -2067,26 +2092,14 @@ s_jxhtml_start_img_tag(void *pdoc, Node *node)
       /*----------------------------------------------------------------------*/
 #ifdef IMG_NOT_CONVERT_FILENAME
       value = chxj_encoding_parameter(r, value);
-      if (value) {
-        value = apr_psprintf(r->pool,
-                             "%s%c%s=true",
-                             value,
-                             (strchr(value, '?')) ? '&' : '?',
-                             CHXJ_COOKIE_NOUPDATE_PARAM);
-      }
+      value = chxj_add_cookie_no_update_parameter(r, value);
       W_L(" src=\"");
       W_V(value);
       W_L("\"");
 #else
       value = chxj_img_conv(r, spec, value);
       value = chxj_encoding_parameter(r, value);
-      if (value) {
-        value = apr_psprintf(r->pool,
-                             "%s%c%s=true",
-                             value,
-                             (strchr(value, '?')) ? '&' : '?',
-                             CHXJ_COOKIE_NOUPDATE_PARAM);
-      }
+      value = chxj_add_cookie_no_update_parameter(r, value);
       W_L(" src=\"");
       W_V(value);
       W_L("\"");
