@@ -1355,9 +1355,10 @@ s_xhtml_1_0_start_form_tag(void *pdoc, Node *node)
   W_L("<form");
   if (attr_action) {
     char *q;
+    char *unused = NULL;
     q = strchr(attr_action, '?');
     if (q) {
-      new_hidden_tag = chxj_form_action_to_hidden_tag(r, doc->pool, attr_action, 1, post_flag);
+      new_hidden_tag = chxj_form_action_to_hidden_tag(r, doc->pool, attr_action, 1, post_flag, &unused, CHXJ_FALSE);
       if (new_hidden_tag) {
         *q = 0;
       }
@@ -2391,13 +2392,7 @@ s_xhtml_1_0_start_img_tag(void *pdoc, Node *node)
     if (STRCASEEQ('s','S',"src",name)) {
       value = chxj_encoding_parameter(r, value);
       value = chxj_add_cookie_parameter(r, value, xhtml->cookie);
-      if (value) {
-        value = apr_psprintf(r->pool,
-                             "%s%c%s=true",
-                             value,
-                             (strchr(value, '?')) ? '&' : '?',
-                             CHXJ_COOKIE_NOUPDATE_PARAM);
-      }
+      value = chxj_add_cookie_no_update_parameter(r, value);
 #ifdef IMG_NOT_CONVERT_FILENAME
 
       W_L(" src=\"");
