@@ -69,6 +69,7 @@
 #include "chxj_serf.h"
 #include "chxj_add_device_env.h"
 #include "chxj_conv_z2h.h"
+#include "chxj_header_inf.h"
 
 
 #define CHXJ_VERSION_PREFIX PACKAGE_NAME "/"
@@ -143,7 +144,8 @@ converter_t convert_routine[] = {
   },
 };
 
-static int chxj_convert_input_header(request_rec *r,chxjconvrule_entry *entryp);
+static int chxj_convert_input_header(request_rec *r,chxjconvrule_entry *entryp, device_table *spec);
+static void s_convert_guid_parameter_to_header(request_rec *r, const char *param, device_table *spec);
 static void s_add_cookie_id_if_has_location_header(request_rec *r, cookie_t *cookie);
 static void s_clear_cookie_header(request_rec *r, device_table *spec);
 
@@ -221,7 +223,7 @@ chxj_headers_fixup(request_rec *r)
                      HTTP_USER_AGENT, 
                      entryp->user_agent);
 
-    chxj_convert_input_header(r,entryp);
+    chxj_convert_input_header(r,entryp, spec);
 
     break;
   
@@ -424,13 +426,45 @@ chxj_convert(request_rec *r, const char **src, apr_size_t *len, device_table *sp
 }
 
 
+/**
+ * convert GUID parameter.
+ *
+ */
+static void
+s_convert_guid_parameter_to_header(request_rec *r, const char *param, device_table *spec)
+{
+  if (strcasecmp(param, "guid") == 0) {
+    switch(spec->html_spec_type) {
+    case CHXJ_SPEC_XHtml_Mobile_1_0:
+      do {
+        char *x_up_subno = (char *)apr_table_get(r->headers_in, "x-up-subno");
+        if (x_up_subno) {
+          apr_table_setn(r->headers_in, "X-DCMGUID", x_up_subno);
+        }
+      } while(0);
+      break;
+    case CHXJ_SPEC_Jhtml:
+    case CHXJ_SPEC_Jxhtml:
+      do {
+        char *x_jphone_uid = (char *)apr_table_get(r->headers_in, "x-jphone-uid");
+        if (x_jphone_uid) {
+          apr_table_setn(r->headers_in, "X-DCMGUID", x_jphone_uid);
+        }
+      } while(0);
+      break;
+    default:
+      break;
+    }
+  }
+}
+
 /**
  * It converts it from HEADER.
  *
  * @param r   [i]
  */
 static int
-chxj_convert_input_header(request_rec *r,chxjconvrule_entry *entryp) 
+chxj_convert_input_header(request_rec *r,chxjconvrule_entry *entryp, device_table *spec) 
 {
 
   char       *buff;
@@ -531,7 +565,7 @@ chxj_convert_input_header(request_rec *r,chxjconvrule_entry *entryp)
         else {
           dname = "";
         }
-
+        s_convert_guid_parameter_to_header(r, dname, spec);
         result = apr_pstrcat(r->pool, result, dname, "=", dvalue, NULL);
       }
       else {
@@ -607,7 +641,8 @@ chxj_input_convert(
   request_rec         *r, 
   const char          **src, 
   apr_size_t          *len, 
-  chxjconvrule_entry  *entryp)
+  chxjconvrule_entry  *entryp,
+  device_table        *spec)
 {
   char     *pair;
   char     *name;
@@ -714,6 +749,7 @@ chxj_input_convert(
           dname = "";
         }
 
+
         result = apr_pstrcat(pool, result, dname, "=", dvalue, NULL);
       }
       else {
@@ -789,6 +825,7 @@ chxj_input_convert(
         else {
           r->args = apr_pstrcat(pool, &name[sizeof(CHXJ_QUERY_STRING_PARAM_PREFIX)-1], "=", dvalue, NULL);
         }
+        s_convert_guid_parameter_to_header(r, &name[sizeof(CHXJ_QUERY_STRING_PARAM_PREFIX)-1], spec);
       }
     }
     else
@@ -806,6 +843,7 @@ chxj_input_convert(
         else {
           r->args = apr_pstrcat(pool, &name[sizeof(CHXJ_QUERY_STRING_PARAM_PREFIX_ENC)-1], "=", dvalue, NULL);
         }
+        s_convert_guid_parameter_to_header(r, &name[sizeof(CHXJ_QUERY_STRING_PARAM_PREFIX_ENC)-1], spec);
       }
     }
     DBG(r, "REQ[%X] ************************ name:[%s]", (unsigned int)(apr_size_t)r, name);
@@ -842,6 +880,8 @@ pass_data_to_filter(ap_filter_t *f, const char *data,
 
   DBG(r, "REQ[%X] start pass_data_to_filter()", (unsigned int)(apr_size_t)r);
 
+  chxj_header_inf_clear(r);
+
   bb = apr_brigade_create(r->pool, c->bucket_alloc);
   b  = apr_bucket_transient_create(data, len, c->bucket_alloc);
 
@@ -933,7 +973,7 @@ chxj_output_filter(ap_filter_t *f, apr_bucket_brigade *bb)
         }
       }
       if (apr_table_get(r->headers_out, "Location") || apr_table_get(r->err_headers_out, "Location")) {
-        if (r->status < HTTP_MULTIPLE_CHOICES || r->status > HTTP_TEMPORARY_REDIRECT) {
+        if (! ap_is_HTTP_REDIRECT(r->status)) {
           r->status = HTTP_MOVED_TEMPORARILY;
         }
       }
@@ -1109,7 +1149,7 @@ chxj_output_filter(ap_filter_t *f, apr_bucket_brigade *bb)
           DBG(r, "REQ[%X] call pass_data_to_filter()", (unsigned int)(apr_size_t)r);
           s_add_cookie_id_if_has_location_header(r, cookie);
           if (apr_table_get(r->headers_out, "Location") || apr_table_get(r->err_headers_out, "Location")) {
-            if (r->status < HTTP_MULTIPLE_CHOICES || r->status > HTTP_TEMPORARY_REDIRECT) {
+            if (! ap_is_HTTP_REDIRECT(r->status)) {
               r->status = HTTP_MOVED_TEMPORARILY;
             }
           }
@@ -1160,7 +1200,7 @@ chxj_output_filter(ap_filter_t *f, apr_bucket_brigade *bb)
           }
         }
         if (apr_table_get(r->headers_out, "Location") || apr_table_get(r->err_headers_out, "Location")) {
-          if (r->status < HTTP_MULTIPLE_CHOICES || r->status > HTTP_TEMPORARY_REDIRECT) {
+          if (! ap_is_HTTP_REDIRECT(r->status)) {
             r->status = HTTP_MOVED_TEMPORARILY;
           }
         }
@@ -1197,7 +1237,7 @@ s_add_cookie_id_if_has_location_header(request_rec *r, cookie_t *cookie)
     apr_table_unset(r->headers_out, "Location");
     apr_table_setn(r->headers_out, "Location", location_header);
     DBG(r, "REQ[%X] Location Header=[%s]", (unsigned int)(apr_size_t)r, location_header);
-    if (r->status < HTTP_MULTIPLE_CHOICES || r->status > HTTP_TEMPORARY_REDIRECT) {
+    if (!ap_is_HTTP_REDIRECT(r->status)) {
       r->status = HTTP_MOVED_TEMPORARILY;
     }
   }
@@ -1219,6 +1259,7 @@ chxj_input_handler(request_rec *r)
   char                *user_agent;
   apr_pool_t          *pool;
   apr_size_t          ii;
+  int                 response_code = 0;
   
   DBG(r, "start of chxj_input_handler()");
 
@@ -1255,7 +1296,7 @@ chxj_input_handler(request_rec *r)
    * now convert.
    */
   if (post_data_len > 0) {
-    post_data = chxj_input_convert(r, (const char**)&post_data, (apr_size_t*)&post_data_len, entryp);
+    post_data = chxj_input_convert(r, (const char**)&post_data, (apr_size_t*)&post_data_len, entryp, spec);
     DBG(r, "(in:exchange)POSTDATA:[%s]", post_data);
   }
 
@@ -1264,7 +1305,7 @@ chxj_input_handler(request_rec *r)
     url_path = apr_psprintf(pool, "%s%s", dconf->forward_url_base, r->uri);
   }
   else {
-    url_path = apr_psprintf(pool, "%s://%s:%d%s", chxj_apache_run_http_scheme(r), "127.0.0.1", ap_get_server_port(r), r->uri);
+    url_path = apr_psprintf(pool, "%s://%s:%d%s", chxj_apache_run_http_scheme(r), ap_get_server_name(r), ap_get_server_port(r), r->uri);
   }
   if (r->args) {
     url_path = apr_pstrcat(pool, url_path, "?", r->args, NULL);
@@ -1275,7 +1316,7 @@ chxj_input_handler(request_rec *r)
   apr_table_setn(r->headers_in, CHXJ_HEADER_ORIG_CLIENT_IP, r->connection->remote_ip);
   apr_table_unset(r->headers_in, "Content-Length");
   apr_table_setn(r->headers_in, "Content-Length", apr_psprintf(pool, "%" APR_SIZE_T_FMT, post_data_len));
-  response = chxj_serf_post(r, pool, url_path, post_data, post_data_len, 1, &res_len);
+  response = chxj_serf_post(r, pool, url_path, post_data, post_data_len, 1, &res_len, &response_code);
   DBG(r, "REQ[%X] -------------------------------------------------------", (unsigned int)(apr_size_t)r);
   DBG(r, "REQ[%X] response length:[%" APR_SIZE_T_FMT "]", (unsigned int)(apr_size_t)r, res_len);
   for (ii=0; ii<res_len/64; ii++) {
@@ -1290,6 +1331,10 @@ chxj_input_handler(request_rec *r)
       apr_table_unset(r->headers_out, "Transfer-Encoding");
     }
   }
+  if (ap_is_HTTP_ERROR(response_code)) {
+    DBG(r, "REQ[%X] end of chxj_input_handler() (HTTP-ERROR received. response code:[%d])", (unsigned int)(apr_size_t)r, response_code);
+    return response_code;
+  }
   {
     apr_pool_t *wpool;
     apr_pool_create(&wpool, r->pool);
@@ -1817,6 +1862,13 @@ chxj_merge_per_dir_config(apr_pool_t *p, void *basev, void *addv)
   else {
     mrg->new_line_type = NLTYPE_NIL;
   }
+
+  if (add->forward_url_base) {
+    mrg->forward_url_base = add->forward_url_base;
+  }
+  else if (base->forward_url_base) {
+    mrg->forward_url_base = base->forward_url_base;
+  }
   return mrg;
 }
 
